@@ -43,7 +43,8 @@ has [qw/
 
 has index_settings => (
     is      => 'ro',
-    isa     => 'Maybe[HashRef]',
+    isa     => 'HashRef',
+    default => sub {{}},
 );
 
 has model => (
